==> openx-2.6.5.tar.bz2: openx-2.6.5/lib/OA/Dashboard/Widgets/Disabled.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.6                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2009 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: Login.php 10874 2007-10-04 15:53:10Z matteo.beccati@openads.org $
*/

require_once MAX_PATH . '/lib/OA/Dashboard/Widget.php';
require_once MAX_PATH . '/lib/max/Admin/Redirect.php';
require_once MAX_PATH . '/lib/OA/Central/Dashboard.php';


/**
 * A class to display the disabled dashboard iframe content
 *
 */
class OA_Dashboard_Widget_Disabled extends OA_Dashboard_Widget
{
    /**
     * A method to launch and display the widget
     *
     */
    function display()
    {
        $aConf = $GLOBALS['_MAX']['CONF'];

        $oTpl = new OA_Admin_Template('dashboard/disabled.html');

        $oDashboard = new OA_Central_Dashboard();
        $oTpl->assign('noSSL', !$oDashboard->oMapper->oRpc->oXml->canUseSSL());
        $oTpl->assign('noDash', !$aConf['ui']['dashboardEnabled']);
        $oTpl->assign('dashUrl', MAX::constructURL(MAX_URL_ADMIN, 'account-settings-user-interface.php'));
        $oTpl->assign('syncUrl', MAX::constructURL(MAX_URL_ADMIN, 'account-settings-update.php'));
        $oTpl->assign('isAdmin',  OA_Permission::isAccount(OA_ACCOUNT_ADMIN));

        $oTpl->display();
    }
}

?>

==> openx-2.8.4.tar.bz2: openx-2.8.4/lib/OA/Dashboard/Widgets/Disabled.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.8                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2009 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: Login.php 10874 2007-10-04 15:53:10Z matteo.beccati@openads.org $
*/

require_once MAX_PATH . '/lib/OA/Dashboard/Widget.php';
require_once MAX_PATH . '/lib/OA/Central/Dashboard.php';

require_once LIB_PATH . '/Admin/Redirect.php';

/**
 * A class to display the disabled dashboard iframe content
 *
 */
class OA_Dashboard_Widget_Disabled extends OA_Dashboard_Widget
{
    /**
     * A method to launch and display the widget
     *
     */
    function display()
    {
        $aConf = $GLOBALS['_MAX']['CONF'];

        $oTpl = new OA_Admin_Template('dashboard/disabled.html');

        $oDashboard = new OA_Central_Dashboard();
        $oTpl->assign('isAdmin',  OA_Permission::isAccount(OA_ACCOUNT_ADMIN));

        $oTpl->display();
    }
}

?>
